      subroutine return_to_unit_triangle(theta, phi, omega, l_degree)

C     Checks whether or not the input orientation (theta, phi, omega)
C     lies within the icosahedral ASU defined by the triangle formed
C     from two adjacent points of fivefold symmetry (90, +/- 31.7) and
C     the nearest three-fold axis (69.0, 0).
C
C     For orientations outside of the ASU, the equivalent point within
C     the ASU is determined by individually applying the 60 rotation
C     matrices.
C      
C     Author: Steve Fuller 12/4/85
C     
C     MRC conversion sdf - 17-jan-87
C     Revision for larger area of return sdf 28-jan-87
C     Modified 1-feb-87 sdf
C     Completely re-written - previous version was wrong sdf 12-jan88
C     
C     Modified: Robert Sinkovits 6/28/06 - general cleanup and bringing
C     in line with Fortran 90 standard

      implicit none

      real*4, intent(inout) :: theta, phi, omega
      logical, intent(in)   :: l_degree

      real*4 dcos(3), x(3)
      real*4 thetar, phir, omegar
      real*4 deg_per_rad/57.29577951/
      real*4 icos_rot(3,3,60)   ! icos rotation matrixes
      
      integer imat
      logical good

C     Initialize icosahedral rotation matricies
      call genrot(icos_rot)

      if(l_degree) then
         call polar_to_cosines(theta, phi, dcos)
      else
         call polar_to_cosines(theta*deg_per_rad,phi*deg_per_rad,dcos)
      end if
      
      if(good(dcos)) return
      
      if(.not.l_degree) then
         theta = theta * deg_per_rad
         phi = phi * deg_per_rad
         omega = omega * deg_per_rad
      else
         call polar_to_cosines( thetar*deg_per_rad,
     1        phir*deg_per_rad,x)          
      end if

      do imat = 1, 60
         call equivalent_view(theta, phi,omega,
     1        icos_rot(1,1,imat),
     1        thetar, phir, omegar)
         call polar_to_cosines(thetar, phir, x)
         if(good(x)) then
            if(l_degree) then
               theta = thetar
               phi = phir
               omega=omegar
               return
            else
               theta = thetar / deg_per_rad
               phi = phir / deg_per_rad
               omega = omegar / deg_per_rad
               return
            end if
         end if
      end do
      
      write(6,'('' return_to_unit_triangle '')')
      write(6,'('' no equivalent found '')')
      write(6,'('' input values '')')
      write(6,'('' theta '',f10.3)') theta
      write(6,'('' phi '',f10.3)') phi
      write(6,'('' omega '',f10.3)') omega
      write(6,'('' last matrix tried '',i2)') imat
      
      return
      end subroutine return_to_unit_triangle
