C  ****************************************************************************
C  *                                                                          *
C  *                *****     SUBROUTINE WRITE_PARAMS     *****               *
C  *                                                                          *
C  *    WRITES OUT THE CURRENT PARAMETER ARRAYS TO NEW PARAMETER FILES        *
C  *     FILES (UNIT = 11).                                                   *
C  *    ALSO NORMALIZES THE MAG SCALE FACTORS IF MAG_NORM SET = TO 1.         *
C  *                                                                          *
C  *    FEBRUARY 1998 PURDUE UNIVERSITY AlphaStation 500/400, T. BAKER.       *
C  *    LAST MODIFIED  6-FEB-1998 BY T. BAKER (Add MAG normalization).        *
C  ****************************************************************************
C
      SUBROUTINE WRITE_PARAMS (NIDS_TOT, FIDS, IDS, TS, PS, OS, 
     1 XS, YS, MAGS, PFT_CCS, PRJ_CCS, CMP_CCS, PARAM_FNAMES, 
     2 IMG_FNAMES, MAG_NORM)
C      
      IMPLICIT NONE
C
      COMMON/CTF_COM/PIXSIZ, UNITS, VOLTS, AMP_FAC, FOCUS_MAJ, 
     1 FOCUS_MIN, ANG_MAJ, CS_COEFF
C
      INTEGER*4 NIDS_TOT, FILE, FILE_LAST, MAG_NORM
      INTEGER*4 ID, FIDS(NIDS_TOT), IDS(NIDS_TOT), UNITS(999)
      REAL*4    PIXSIZ(999), VOLTS(999), AMP_FAC(999), CS_COEFF(999)
      REAL*4    FOCUS_MAJ(999), FOCUS_MIN(999)
      REAL*4    ANG_MAJ(999), MAG_FACTOR
      REAL*4    TS(NIDS_TOT), PS(NIDS_TOT), OS(NIDS_TOT)
      REAL*4    XS(NIDS_TOT), YS(NIDS_TOT), MAGS(NIDS_TOT)
      REAL*4    PFT_CCS(NIDS_TOT), PRJ_CCS(NIDS_TOT), CMP_CCS(NIDS_TOT)
      CHARACTER(len=256) PARAM_FNAMES(999), IMG_FILENAME
      CHARACTER(len=256) IMG_FNAMES(999), NEW_FNAME
C  ---------------------------------------------------------------
C
C  *****************************************************
C  *    NORMALIZE MAG SCALE FACTORS IF MAG_NORM = 1    *
C  *****************************************************
      IF(MAG_NORM.EQ.1) THEN
        MAG_FACTOR = 0.0
        DO ID = 1, NIDS_TOT
          MAG_FACTOR = MAG_FACTOR + MAGS(ID)
        ENDDO
        MAG_FACTOR = MAG_FACTOR/FLOAT(NIDS_TOT)
        WRITE(*,'(A,F8.4,A)') ' Mean of MAG scale factors (=', 
     1  MAG_FACTOR,') normalized to 1.0'
        MAG_FACTOR = 1.0/MAG_FACTOR
        DO ID = 1, NIDS_TOT
          MAGS(ID) = MAGS(ID)*MAG_FACTOR
        ENDDO
      ENDIF
C
      CALL INCREMENT_FNAME (PARAM_FNAMES(1), NEW_FNAME)
Ca      This filename already guaranteed to be new in PFILE_INFO() above
Ca      See call to chk_file_exists()
      OPEN (UNIT=11, FILE=NEW_FNAME,
     1 ACCESS='SEQUENTIAL', FORM='FORMATTED')
      IMG_FILENAME = IMG_FNAMES(1)
      IF(IMG_FILENAME(1:1).EQ.' ') THEN
         WRITE(11,'(A)') TRIM(ADJUSTL(IMG_FILENAME))
       ELSE
         WRITE(11,'(A)') ' '//TRIM(ADJUSTL(IMG_FILENAME))
      ENDIF
      WRITE(11,1010) PIXSIZ(1), UNITS(1), VOLTS(1), AMP_FAC(1), 
     1 FOCUS_MAJ(1), FOCUS_MIN(1), ANG_MAJ(1), CS_COEFF(1)
      FILE_LAST = FIDS(1)
C
      DO ID = 1,NIDS_TOT
        FILE = FIDS(ID)
        IF(FILE_LAST.NE.FILE) THEN
          CLOSE (UNIT=11)
          CALL INCREMENT_FNAME (PARAM_FNAMES(FILE), NEW_FNAME)
          OPEN (UNIT=11, FILE=NEW_FNAME, STATUS='NEW',
     1         ACCESS='SEQUENTIAL', FORM='FORMATTED')
          IMG_FILENAME = IMG_FNAMES(FILE)
          IF(IMG_FILENAME(1:1).EQ.' ') THEN
             WRITE(11,'(A)') TRIM(ADJUSTL(IMG_FILENAME))
          ELSE
             WRITE(11,'(A)') ' '
     1            //TRIM(ADJUSTL(IMG_FILENAME))
          ENDIF
          WRITE(11,1010) PIXSIZ(FILE), UNITS(FILE), VOLTS(FILE), 
     1    AMP_FAC(FILE), FOCUS_MAJ(FILE), FOCUS_MIN(FILE), 
     2    ANG_MAJ(FILE), CS_COEFF(FILE)
          FILE_LAST = FIDS(ID)
        ENDIF
        WRITE(11,1020) IDS(ID), TS(ID), PS(ID), OS(ID), XS(ID), YS(ID),
     1  MAGS(ID), PFT_CCS(ID), PRJ_CCS(ID), CMP_CCS(ID)
      ENDDO
      CLOSE (UNIT=11)

       RETURN
 1010  FORMAT (1X,F8.4,',',I2,',',F10.1,',',3(F10.4,','),F10.4,',',F8.2)
 1020  FORMAT (1X,I6,',',4(F8.3,','),F7.3,',',3(F6.3,','),F6.3)

      END
